/******************************************************************************

	nw_cntl.h
	
******************************************************************************/

#ifndef _NW_CNTL
#define _NW_CNTL

/******************************************************************************

	macros
	
******************************************************************************/

#define ARG_MAX			50
#define TRY_MAX			5

#define init_args(al)   _init_args(&al);
#define free_args(al)   _free_args(&al);

/******************************************************************************

	structures
	
******************************************************************************/

typedef struct
{
  
  int argc;
  char *argv[ARG_MAX];

} arg_list_t, * arg_list;

/******************************************************************************

	global variables
	
******************************************************************************/

// defaults
char default_opt[PATH_MAX]  = "";

const char *defaults[] =
{
	"--no-defaults",
	"--defaults-file=",
	"--defaults-extra-file=",
	NULL
};

// options
char hostname[PATH_MAX];
char datadir[PATH_MAX]      = "";
char pid_file[PATH_MAX]     = "";
char err_log[PATH_MAX]      = "";
char out_log[PATH_MAX]      = "";
char autoclose = FALSE;

typedef struct
{
	const char *name;
	char *value;
} option_t;

option_t options[] = 
{
	{"--datadir=",    datadir},
	{"--pid-file=",   pid_file},
	{"--err-log=",    err_log},
	{"--autoclose",   &autoclose},
	{NULL,            NULL}
};

/******************************************************************************

	prototypes
	
******************************************************************************/

void _init_args(arg_list *);
void add_arg(arg_list, char *, ...);
void _free_args(arg_list *);
int sleep_until_file_exists(char *);
int sleep_until_file_deleted(char *);
int wait_for_server_start(char *, char *, char *, int);
int spawn(char *, arg_list, int, char *, char *, char *);
int stop_server(char *, char *, char *, int, char *);
int kill_server(char *);
void del_tree(char *);
void read_defaults(char *, arg_list);
void parse_args(int argc, char *argv[]);
void get_options(char *, char *, int argc, char *argv[]);
void log(char *, ...);
void vlog(char *, va_list);
void die(char *, ...);
void get_base_dirs(char *, char *, char *);

#endif /* _NW_CNTL */
