/* Anantha Kesari. 20 Aug 2003. DEFECT500290625
 *
 * Define PTHREADS only for Apache 2 and not for Apache 1.3.
 * This is because the former is LibC based and everything works fine in that case.
 * The latter is Clib based and so the thread calls will change if we use PTHREADS
 * and the server abends if we use PTHREADS in PHP for Apache 1.3.
 *
 * Explanation:
 *
 * In the case of Apache 1.3, pthread_self always returns 0 due to mismatch in
 * the function calls used to create the treads and getting the IDs for them.
 * (Threads are created by Apache 1.3 using Clib calls whereas LibC's PTHREAD call
 * is used to get the ID for these threads).
 * Now, using this thread specific ID returned by pthread_self, we store some
 * thread specific data into different hash tables. When we execute multiple scripts
 * simultaneously, since the ID is always 0, one thread reads/writs data from/into
 * another thread's data area.
 * This causes the server to abend.
 */
#ifdef APACHE_2_BUILD
#define PTHREADS
#else
#undef PTHREADS
#endif
