/*
   +----------------------------------------------------------------------+
   | Zend Engine                                                          |
   +----------------------------------------------------------------------+
   | Copyright (c) 1998-2002 Zend Technologies Ltd. (http://www.zend.com) |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.00 of the Zend license,     |
   | that is bundled with this package in the file LICENSE, and is        | 
   | available at through the world-wide-web at                           |
   | http://www.zend.com/license/2_00.txt.                                |
   | If you did not receive a copy of the Zend license and are unable to  |
   | obtain it through the world-wide-web, please send a note to          |
   | license@zend.com so we can mail you a copy immediately.              |
   +----------------------------------------------------------------------+
   | Authors: Andi Gutmans <andi@zend.com>                                |
   |          Zeev Suraski <zeev@zend.com>                                |
   | Modified for NetWare: Novell, Inc.                                   |
   +----------------------------------------------------------------------+
*/


#ifndef ZEND_CONFIG_NW_H
#define ZEND_CONFIG_NW_H


#include <string.h>
#include <float.h>

typedef unsigned long ulong;
typedef unsigned int uint;

/* Though we have alloca(), this seems to be causing some problem
 * with the stack pointer. Hence not using it
 */
/*#define HAVE_ALLOCA 1*/
#define HAVE_LIMITS_H 1

#undef HAVE_KILL
#define HAVE_GETPID 1
/*#define HAVE_ALLOCA_H 1*/
#define HAVE_MEMCPY 1
#define HAVE_STRDUP 1
#define HAVE_SYS_TYPES_H 1
/*#define HAVE_STDIOSTR_H 1*/
#define HAVE_CLASS_ISTDIOSTREAM
#define istdiostream stdiostream
#define HAVE_STDARG_H	1
#define HAVE_SNPRINTF	1
#define HAVE_VSNPRINTF	1

#define HAVE_STRING_H

/* For now, to possibly avoid a whole lot of compiler cribs */
#define ZEND_ENABLE_FAST_CACHE 0
/*#define ZEND_DISABLE_MEMORY_CACHE 1*/

#define zend_sprintf sprintf


/* Below, till end:
 * From acconfig.h file. This is done to remove the dependency
 * on that file since that file will be removed soon by PHP group.
 * The blelow is what is required from acconfig.h for NetWare.
 */

#define ZEND_API
#define ZEND_DLEXPORT


#ifdef HAVE_ISNAN
#define zend_isnan(a) isnan(a)
#elif defined(NAN)
#define zend_isnan(a) (((a)==NAN)?1:0)
#elif defined(HAVE_FPCLASS)
#define zend_isnan(a) ((fpclass(a) == FP_SNAN) || (fpclass(a) == FP_QNAN))
#else
#define zend_isnan(a) 0
#endif

#ifdef HAVE_ISINF
#define zend_isinf(a) isinf(a)
#elif defined(INFINITY)
/* Might not work, but is required by ISO C99 */
#define zend_isinf(a) (((a)==INFINITY)?1:0)
#elif defined(HAVE_FPCLASS)
#define zend_isinf(a) ((fpclass(a) == FP_PINF) || (fpclass(a) == FP_NINF))
#else
#define zend_isinf(a) 0
#endif

#ifdef HAVE_FINITE
#define zend_finite(a) finite(a)
#elif defined(HAVE_ISFINITE) || defined(isfinite)
#define zend_finite(a) isfinite(a)
#elif defined(fpclassify)
#define zend_finite(a) ((fpclassify((a))!=FP_INFINITE&&fpclassify((a))!=FP_NAN)?1:0)
#else
#define zend_finite(a) (zend_isnan(a) ? 0 : zend_isinf(a) ? 0 : 1)
#endif

/* Anantha Kesari. 20 Aug 2003. DEFECT500290625
 *
 * Define PTHREADS only for Apache 2 and not for Apache 1.3.
 * This is because the former is LibC based and everything works fine in that case.
 * The latter is Clib based and so the thread calls will change if we use PTHREADS
 * and the server abends if we use PTHREADS in PHP for Apache 1.3.
 *
 * Explanation:
 *
 * In the case of Apache 1.3, pthread_self always returns 0 due to mismatch in
 * the function calls used to create the treads and getting the IDs for them.
 * (Threads are created by Apache 1.3 using Clib calls whereas LibC's PTHREAD call
 * is used to get the ID for these threads).
 * Now, using this thread specific ID returned by pthread_self, we store some
 * thread specific data into different hash tables. When we execute multiple scripts
 * simultaneously, since the ID is always 0, one thread reads/writs data from/into
 * another thread's data area.
 * This causes the server to abend.
 */
#ifdef APACHE_2_BUILD
#define PTHREADS
#else
#undef PTHREADS
#endif

#endif /* ZEND_CONFIG_NW_H */
